"""
Scenario information, used to run simulations and create graphs.

The Hinwood study consisted of four scenarios each conducted twice, leading to
8 experiments in total.
"""

# A list of scenario dictionaries
# Each element will represent one experiment (8 in the Hinwood study) 
scenarios = []



# Experiment S1R1
offshore_water_depth = .4
data = {'xleft':[-3.106,0.0 - offshore_water_depth],  # Av' of ADV and Gauge A
        'xtoe':[0.0,0.0 - offshore_water_depth],
        'xbeach':[1.285,0.090 - offshore_water_depth],
        'xright':[8,.4843334 - offshore_water_depth],
        'offshore_water_depth': offshore_water_depth,
        'scenario_id':'S1R1',
        'gauge_names':['B','1','2','3','4','5','7'],
        'gauge_x':[-0.68, 1.569, 2.568, 3.566, 4.564, 5.562, 7.559],
        'break_xs':[5.45, 5.58, 5.29, 5.245, 5.21, 5.21],
        'break_type':['none', 'plunge', 'plunge', 'plunge', 'plunge', \
                      'plunge'],
        'wave_times':[20.0, 59.0]
        }
scenarios.append(data)

# Experiment S1R2
data = {'xleft':[-3.106,0.0 - offshore_water_depth],  # Av' of ADV and Gauge A
        'xtoe':[0.0,0.0 - offshore_water_depth],
        'xbeach':[1.285,0.090 - offshore_water_depth],
        'xright':[8,.4843334 - offshore_water_depth],
        'offshore_water_depth':offshore_water_depth,
        'scenario_id':'S1R2',
        'gauge_names':['B','1','2','3','4','5','7'],
        'gauge_x':[-0.68, 1.569, 2.568, 3.566, 4.564, 5.562, 7.559],
        'break_xs':[5.45, 5.45, 5.28, 5.28, 5.29, 5.29],
        'break_type':['none', 'plunge', 'plunge', 'plunge', 'plunge', \
                      'plunge'],
        'wave_times':[23.0, 59.0]
                 }
scenarios.append(data)


# Experiment S2R1
data = {'xleft':[-4.586,0.0 - offshore_water_depth],  # Av' of ADV and Gauge A
        'xtoe':[0.0,0.0 - offshore_water_depth],
        'xbeach':[1.285,0.090 - offshore_water_depth],
        'xright':[8,.4843334 - offshore_water_depth],
        'offshore_water_depth':offshore_water_depth,
        'scenario_id':'S2R1',
        'gauge_names':['B','1','2','3','4','5'],
        'gauge_x':[-0.68, 1.569, 2.568, 3.566, 4.564, 5.562],
        'break_xs':[5.93, 5.93, 5.907, 5.78], # since depth finishes at 65 sec
        'break_type':['none', 'front steepened', 'front steepened', 'spill'],
        'wave_times':[15.0, 64.0]
                 }
scenarios.append(data)

# Experiment S2R2
data = {'xleft':[-4.586,0.0 - offshore_water_depth],  # Av' of ADV and Gauge A
        'xtoe':[0.0,0.0 - offshore_water_depth],
        'xbeach':[1.285,0.090 - offshore_water_depth],
        'xright':[8,.4843334 - offshore_water_depth],
        'offshore_water_depth':offshore_water_depth,
        'scenario_id':'S2R2',
        'gauge_names':['B','1','2','3','4','5'],
        'gauge_x':[-0.68, 1.569, 2.568, 3.566, 4.564, 5.562],
        'break_xs':[6.32, 6.32, 6.033, 5.935],  # since depth finishes at 75 sec
        'break_type':['none', 'front steepened', 'front steepened',
                      'weak break'],
        'wave_times':[34.0, 74.0]
        }
scenarios.append(data)


# Experiment S3R1
# Now the slope has changed - and when tank was refilled the depth also changed
offshore_water_depth = .336
data = {'xleft':[-3.875,0.0 - offshore_water_depth],  # Av' of ADV and Gauge A
        'xtoe':[0.0,0.0 - offshore_water_depth],
        'xbeach':[1.285,0.090 - offshore_water_depth],
        'xright':[14.,.3903881 - offshore_water_depth],
        'offshore_water_depth':offshore_water_depth,
        'scenario_id':'S3R1',
        'gauge_names':['B','1','2','3','5','7',
                       '9','10','11','12'],

        'gauge_x':[-0.325, 1.572, 2.571, 3.571, 5.57,
                   7.57, 9.569, 10.569, 11.569,
                   12.569],
        'break_xs':[9.063, 9.063, 9.043, 9.043],
        'break_type':['none','collapse', 'collapse', 'collapse'],
        'wave_times':[30.0, 74.0]
                 }
scenarios.append(data)

# Experiment S3R2
data = {'xleft':[-3.875,0.0 - offshore_water_depth],  # Av' of ADV and Gauge A
        'xtoe':[0.0,0.0 - offshore_water_depth],
        'xbeach':[1.285,0.090 - offshore_water_depth],
        'xright':[14.,.3903881 - offshore_water_depth],
        'offshore_water_depth':offshore_water_depth,
        'scenario_id':'S3R2',
        'gauge_names':['B','1','2','3','5','7',
                       '9','10','11','12'],

        'gauge_x':[-0.325, 1.572, 2.571, 3.571, 5.57,
                   7.57, 9.569, 10.569, 11.569,
                   12.569],
        'break_xs':[9.17, 9.135, 9.135, 9.105],
        'break_type':['collapse', 'collapse', 'collapse',
                      'collapse'],
        'wave_times':[30.0, 85.0]
        }
scenarios.append(data)

# Experiment S4R1
data = {'xleft':[-2.43,0.0 - offshore_water_depth],  # Av' of ADV and Gauge A
        'xtoe':[0.0,0.0 - offshore_water_depth],
        'xbeach':[1.285,0.090 - offshore_water_depth],
        'xright':[14.,.3903881 - offshore_water_depth],
        'offshore_water_depth':offshore_water_depth,
        'scenario_id':'S4R1',   
        'gauge_names':['B','1','2','3','5','7',
                       '9','10','11','12'],
        'gauge_x':[-0.325, 1.572, 2.571, 3.571, 5.57,
                   7.57, 9.569, 10.569, 11.569,
                   12.569],
        'break_xs':[7.673, 7.673, 7.43, 7.448, 7.448], # Pressure info ends early
        'break_type':['none','spill', 'spill', 'spill', 'spill'],
        'wave_times':[34.0, 75.0]
        }
scenarios.append(data)

# Experiment S4R2
data = {'xleft':[-2.43,0.0 - offshore_water_depth],  # Av' of ADV and Gauge A
        'xtoe':[0.0,0.0 - offshore_water_depth],
        'xbeach':[1.285,0.090 - offshore_water_depth],
        'xright':[14.,.3903881 - offshore_water_depth],
        'offshore_water_depth':offshore_water_depth,
        'scenario_id':'S4R2',      
        'gauge_names':['B','1','2','3','5','7',
                       '9','10','11','12'],

        'gauge_x':[-0.325, 1.572, 2.571, 3.571, 5.57,
                   7.57, 9.569, 10.569, 11.569,
                   12.569],
        'break_xs':[8.53, 7.46, 7.492, 7.492, 7.444],
        'break_type':['collapse', 'spill', 'spill', 'spill', 'spill'],
        'wave_times':[34.0, 75.0]
        }
scenarios.append(data)

